@@ -3,20 +3,20 @@ import datetime
 import importlib
 import math
 
+from lifelines import KaplanMeierFitter 
+import matplotlib.pyplot as plt
 import numpy as np 
 import pandas as pd 
-import tensorflow as tf 
-from tensorflow.contrib.layers import fully_connected as FC_Net 
-from sklearn.metrics import brier_score_loss 
-from sklearn.model_selection import train_test_split 
-from lifelines import KaplanMeierFitter 
-import matplotlib.pyplot as plt 
-from sklearn.metrics import roc_auc_score
-from sklearn.preprocessing import LabelEncoder
-import sklearn.metrics as metrics
 from termcolor import colored
 from scipy import stats
 import pickle as pkl
+import tensorflow as tf 
+from tensorflow.contrib.layers import fully_connected as FC_Net 
+from sklearn.preprocessing import LabelEncoder
+#from sklearn.metrics import brier_score_loss, train_test_split,  roc_auc_score
+#from sklearn.model_selection import  
+#from sklearn.metrics import
+#import sklearn.metrics as metrics
 
 '''
 This declare DeepHit architecture:
@@ -43,7 +43,86 @@ LOSS FUNCTIONS:
 global _EPSILON
 _EPSILON = 1e-08
 
+### MASK FUNCTIONS
+'''
+    fc_mask2      : To calculate LOSS_1 (log-likelihood loss)
+    fc_mask3      : To calculate LOSS_2 (ranking loss)
+'''
+def impt_f_get_fc_mask2(time, label, num_Event, num_Category):
+    '''
+        mask4 is required to get the log-likelihood loss
+        mask4 size is [N, num_Event, num_Category]
+            if not censored : one element = 1 (0 elsewhere)
+            if censored     : fill elements with 1 after the censoring time (for all events)
+    '''
+    #print('impt_f_get_fc_mask2')
+    mask = np.zeros([np.shape(time)[0], num_Event, num_Category]) # for the first loss function
+    for i in range(np.shape(time)[0]):
+        if label[i,0] != 0:  #not censored
+            mask[i,int(label[i,0]-1),int(time[i,0])] = 1
+        else: #label[i,2]==0: censored
+            mask[i,:,int(time[i,0]+1):] =  1 #fill 1 until from the censoring time (to get 1 - \sum F)
+    return mask
 
+
+def impt_f_get_fc_mask3(time, meas_time, num_Category):
+    '''
+        mask5 is required calculate the ranking loss (for pair-wise comparision)
+        mask5 size is [N, num_Category].
+        - For longitudinal measurements:
+             1's from the last measurement to the event time (exclusive and inclusive, respectively)
+             denom is not needed since comparing is done over the same denom
+        - For single measurement:
+             1's from start to the event time(inclusive)
+    '''
+    # print('impt_f_get_fc_mask3')
+    mask = np.zeros([np.shape(time)[0], num_Category]) # for the first loss function
+    if np.shape(meas_time):  #lonogitudinal measurements
+        for i in range(np.shape(time)[0]):
+            t1 = int(meas_time[i, 0]) # last measurement time
+            t2 = int(time[i, 0]) # censoring/event time
+            mask[i,(t1+1):(t2+1)] = 1  #this excludes the last measurement time and includes the event time
+    else:                    #single measurement
+        for i in range(np.shape(time)[0]):
+            t = int(time[i, 0]) # censoring/event time
+            mask[i,:(t+1)] = 1  #this excludes the last measurement time and includes the event time
+    return mask
+
+# los function
+########## ADAPTED IMPORT FOR LOS
+def get_Normalization_los(dffeatures, data_stats): # only implemented standard, but can include max-min type in the future
+    # print('get_Normalization_los')
+    data=dffeatures
+    for feat in dffeatures.columns:
+        if data_stats.loc[feat,'std'] !=0:
+            data[feat]=(dffeatures[feat] - data_stats.loc[feat,'mean'])/data_stats.loc[feat,'std']
+        else:
+            data[feat]=(dffeatures[feat] - data_stats.loc[feat,'mean'])
+    return np.asarray(data)
+
+
+def import_dataset_los_old(dflabel,dfval,dffeatures,data_stats,num_Category,num_Event,x_dim):
+    # print('import_dataset_los')
+    label           = np.asarray(dflabel)
+    time            = np.asarray(dfval)
+    data            = get_Normalization_los(dffeatures,data_stats)
+    mask1           = impt_f_get_fc_mask2(time, label, num_Event, num_Category)
+    mask2           = impt_f_get_fc_mask3(time, -1, num_Category)
+    DIM             = (x_dim)
+    DATA            = (data, time, label)
+    MASK            = (mask1, mask2)
+    
+    return DIM, DATA, MASK
+
+def import_dataset_los(dffeatures,data_stats,num_Category,num_Event,x_dim):
+    label           = np.asarray([[1]]) # arbitrary, adaptation for pred.
+    time            = np.asarray([[700]])
+    data            = get_Normalization_los(dffeatures,data_stats)
+    mask1           = impt_f_get_fc_mask2(time, label, num_Event, num_Category)
+    mask2           = impt_f_get_fc_mask3(time, -1, num_Category)
+    MASK            = (mask1, mask2)
+
+    return data, MASK
 def test(x):
     print('x = ', x)
 
@@ -162,8 +241,8 @@ class Model_DeepHit:
 
     ### LOSS-FUNCTION 2 -- Ranking loss
     def loss_Ranking(self):
-#x        sigma1 = tf.constant(0.1, dtype=tf.float32)
-#x        sigma1 = tf.constant(0.65, dtype=tf.float32)
+        #x        sigma1 = tf.constant(0.1, dtype=tf.float32)
+        #x        sigma1 = tf.constant(0.65, dtype=tf.float32)
         
         sigma1 = tf.constant(0.65, dtype=tf.float32)
         eta = []
@@ -478,111 +557,7 @@ Once must construct a function similar to "import_dataset_SYNTHETIC":
     - Based on the data, creat mask1 and mask2 that are required to calculate loss functions.
 '''
 
-
-##### DEFINE USER-FUNCTIONS #####
-def impt_f_get_Normalization(X, norm_mode):
-    num_Patient, num_Feature = np.shape(X)
-
-    if norm_mode == 'standard': #zero mean unit variance
-        for j in range(num_Feature):
-            if np.std(X[:,j]) != 0:
-                X[:,j] = (X[:,j] - np.mean(X[:, j]))/np.std(X[:,j])
-            else:
-                X[:,j] = (X[:,j] - np.mean(X[:, j]))
-    elif norm_mode == 'normal': #min-max normalization
-        for j in range(num_Feature):
-            X[:,j] = (X[:,j] - np.min(X[:,j]))/(np.max(X[:,j]) - np.min(X[:,j]))
-    else:
-        print("INPUT MODE ERROR!")
-
-    return X
-
-### MASK FUNCTIONS
-'''
-    fc_mask2      : To calculate LOSS_1 (log-likelihood loss)
-    fc_mask3      : To calculate LOSS_2 (ranking loss)
-'''
-def impt_f_get_fc_mask2(time, label, num_Event, num_Category):
-    '''
-        mask4 is required to get the log-likelihood loss
-        mask4 size is [N, num_Event, num_Category]
-            if not censored : one element = 1 (0 elsewhere)
-            if censored     : fill elements with 1 after the censoring time (for all events)
-    '''
-    mask = np.zeros([np.shape(time)[0], num_Event, num_Category]) # for the first loss function
-    for i in range(np.shape(time)[0]):
-        if label[i,0] != 0:  #not censored
-            mask[i,int(label[i,0]-1),int(time[i,0])] = 1
-        else: #label[i,2]==0: censored
-            mask[i,:,int(time[i,0]+1):] =  1 #fill 1 until from the censoring time (to get 1 - \sum F)
-    return mask
-
-
-def impt_f_get_fc_mask3(time, meas_time, num_Category):
-    '''
-        mask5 is required calculate the ranking loss (for pair-wise comparision)
-        mask5 size is [N, num_Category].
-        - For longitudinal measurements:
-             1's from the last measurement to the event time (exclusive and inclusive, respectively)
-             denom is not needed since comparing is done over the same denom
-        - For single measurement:
-             1's from start to the event time(inclusive)
-    '''
-    mask = np.zeros([np.shape(time)[0], num_Category]) # for the first loss function
-    if np.shape(meas_time):  #lonogitudinal measurements
-        for i in range(np.shape(time)[0]):
-            t1 = int(meas_time[i, 0]) # last measurement time
-            t2 = int(time[i, 0]) # censoring/event time
-            mask[i,(t1+1):(t2+1)] = 1  #this excludes the last measurement time and includes the event time
-    else:                    #single measurement
-        for i in range(np.shape(time)[0]):
-            t = int(time[i, 0]) # censoring/event time
-            mask[i,:(t+1)] = 1  #this excludes the last measurement time and includes the event time
-    return mask
-
-# los function
-########## ADAPTED IMPORT FOR LOS
-def get_Normalization_los(dffeatures, data_stats): # only implemented standard, but can include max-min type in the future
-    ##print('get_Normalization_los')
-    data=dffeatures
-    for feat in dffeatures.columns:
-        if data_stats.loc[feat,'std'] !=0:
-            data[feat]=(dffeatures[feat] - data_stats.loc[feat,'mean'])/data_stats.loc[feat,'std']
-        else:
-            data[feat]=(dffeatures[feat] - data_stats.loc[feat,'mean'])
-    return np.asarray(data)
-
-
-def import_dataset_los(dflabel,dfval,dffeatures,data_stats,norm_mode=True):
     
-    label           = np.asarray(dflabel)
-    time            = np.asarray(dfval)
-    ##print('norm_mode:', norm_mode, '<import_dataset_los>')
-    if norm_mode:
-        data            = get_Normalization_los(dffeatures,data_stats)
-    else:
-        data            = np.asarray(dffeatures)
-    ## print('data=', data)
-    
-    num_Category    = int(np.max(time) * 1.2)  #to have enough time-horizon
-    ## print('num_Category:', num_Category)
-    num_Event       = int(len(np.unique(label))) #only count the number of events (do not count censoring as an event)
-    
-    x_dim           = np.shape(data)[1]
-
-    ##print('A')
-    mask1           = impt_f_get_fc_mask2(time, label, num_Event, num_Category)
-    ##print('B')
-    mask2           = impt_f_get_fc_mask3(time, -1, num_Category)
-    ##print('C')
-    DIM             = (x_dim)
-    DATA            = (data, time, label)
-    MASK            = (mask1, mask2)
-
-    return DIM, DATA, MASK
-
- 
-
 ### random with replace minibatches function    
 def f_get_minibatch(mb_size, x, label, time, mask1, mask2):
     idx = range(np.shape(x)[0])
@@ -636,7 +611,7 @@ def final_prediction(pred):
 
             predlosmean = np.multiply(pred3, np.arange(1,pred3.shape[1]+1,1))
             xlos=predlosmean.cumsum(axis=1)[:,pred3.shape[1]-1]
-            categorization=1
+            categorization=0,1,2,-99
 
       return xlos, categorization 
 
